@@ -1,5 +1,12 @@
 context("EQ-5D-Y")
 
+test_that("EQ-5D-Y Australia gives correct answer", {
+  expect_equal(eq5dy3l(c(MO=1,SC=1,UA=1,PD=1,AD=1), "Australia"), 1)
+  expect_equal(eq5dy3l(c(MO=1,SC=2,UA=1,PD=1,AD=1), "Australia"), 0.977)
+  expect_equal(eq5dy3l(c(MO=2,SC=3,UA=3,PD=3,AD=3), "Australia"), 0.188)
+  expect_equal(eq5dy3l(c(MO=3,SC=3,UA=3,PD=3,AD=3), "Australia"), 0.142)
+})
+
 test_that("EQ-5D-Y Belgium gives correct answer", {
   expect_equal(eq5dy3l(c(MO=1,SC=1,UA=1,PD=1,AD=1), "Belgium"), 1)
   expect_equal(eq5dy3l(c(MO=1,SC=2,UA=3,PD=2,AD=1), "Belgium"), 0.516)
